==> pike7.4_7.4.97.orig.tar.gz: pike7.4-7.4.97.orig/src/language.h <==
/* A Bison parser, made by GNU Bison 1.875a.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOK_ARROW = 258,
     TOK_CONSTANT = 259,
     TOK_FLOAT = 260,
     TOK_STRING = 261,
     TOK_NUMBER = 262,
     TOK_INC = 263,
     TOK_DEC = 264,
     TOK_RETURN = 265,
     TOK_EQ = 266,
     TOK_GE = 267,
     TOK_LE = 268,
     TOK_NE = 269,
     TOK_NOT = 270,
     TOK_LSH = 271,
     TOK_RSH = 272,
     TOK_LAND = 273,
     TOK_LOR = 274,
     TOK_SWITCH = 275,
     TOK_SSCANF = 276,
     TOK_CATCH = 277,
     TOK_FOREACH = 278,
     TOK_LEX_EOF = 279,
     TOK_ADD_EQ = 280,
     TOK_AND_EQ = 281,
     TOK_ARRAY_ID = 282,
     TOK_BREAK = 283,
     TOK_CASE = 284,
     TOK_CLASS = 285,
     TOK_COLON_COLON = 286,
     TOK_CONTINUE = 287,
     TOK_DEFAULT = 288,
     TOK_DIV_EQ = 289,
     TOK_DO = 290,
     TOK_DOT_DOT = 291,
     TOK_DOT_DOT_DOT = 292,
     TOK_ELSE = 293,
     TOK_ENUM = 294,
     TOK_EXTERN = 295,
     TOK_FLOAT_ID = 296,
     TOK_FOR = 297,
     TOK_FUNCTION_ID = 298,
     TOK_GAUGE = 299,
     TOK_GLOBAL = 300,
     TOK_IDENTIFIER = 301,
     TOK_IF = 302,
     TOK_IMPORT = 303,
     TOK_INHERIT = 304,
     TOK_INLINE = 305,
     TOK_LOCAL_ID = 306,
     TOK_FINAL_ID = 307,
     TOK_INT_ID = 308,
     TOK_LAMBDA = 309,
     TOK_MULTISET_ID = 310,
     TOK_MULTISET_END = 311,
     TOK_MULTISET_START = 312,
     TOK_LSH_EQ = 313,
     TOK_MAPPING_ID = 314,
     TOK_MIXED_ID = 315,
     TOK_MOD_EQ = 316,
     TOK_MULT_EQ = 317,
     TOK_NO_MASK = 318,
     TOK_OBJECT_ID = 319,
     TOK_OR_EQ = 320,
     TOK_PRIVATE = 321,
     TOK_PROGRAM_ID = 322,
     TOK_PROTECTED = 323,
     TOK_PREDEF = 324,
     TOK_PUBLIC = 325,
     TOK_RSH_EQ = 326,
     TOK_STATIC = 327,
     TOK_STRING_ID = 328,
     TOK_SUB_EQ = 329,
     TOK_TYPEDEF = 330,
     TOK_TYPEOF = 331,
     TOK_VARIANT = 332,
     TOK_VOID_ID = 333,
     TOK_WHILE = 334,
     TOK_XOR_EQ = 335,
     TOK_OPTIONAL = 336
   };
#endif
#define TOK_ARROW 258
#define TOK_CONSTANT 259
#define TOK_FLOAT 260
#define TOK_STRING 261
#define TOK_NUMBER 262
#define TOK_INC 263
#define TOK_DEC 264
#define TOK_RETURN 265
#define TOK_EQ 266
#define TOK_GE 267
#define TOK_LE 268
#define TOK_NE 269
#define TOK_NOT 270
#define TOK_LSH 271
#define TOK_RSH 272
#define TOK_LAND 273
#define TOK_LOR 274
#define TOK_SWITCH 275
#define TOK_SSCANF 276
#define TOK_CATCH 277
#define TOK_FOREACH 278
#define TOK_LEX_EOF 279
#define TOK_ADD_EQ 280
#define TOK_AND_EQ 281
#define TOK_ARRAY_ID 282
#define TOK_BREAK 283
#define TOK_CASE 284
#define TOK_CLASS 285
#define TOK_COLON_COLON 286
#define TOK_CONTINUE 287
#define TOK_DEFAULT 288
#define TOK_DIV_EQ 289
#define TOK_DO 290
#define TOK_DOT_DOT 291
#define TOK_DOT_DOT_DOT 292
#define TOK_ELSE 293
#define TOK_ENUM 294
#define TOK_EXTERN 295
#define TOK_FLOAT_ID 296
#define TOK_FOR 297
#define TOK_FUNCTION_ID 298
#define TOK_GAUGE 299
#define TOK_GLOBAL 300
#define TOK_IDENTIFIER 301
#define TOK_IF 302
#define TOK_IMPORT 303
#define TOK_INHERIT 304
#define TOK_INLINE 305
#define TOK_LOCAL_ID 306
#define TOK_FINAL_ID 307
#define TOK_INT_ID 308
#define TOK_LAMBDA 309
#define TOK_MULTISET_ID 310
#define TOK_MULTISET_END 311
#define TOK_MULTISET_START 312
#define TOK_LSH_EQ 313
#define TOK_MAPPING_ID 314
#define TOK_MIXED_ID 315
#define TOK_MOD_EQ 316
#define TOK_MULT_EQ 317
#define TOK_NO_MASK 318
#define TOK_OBJECT_ID 319
#define TOK_OR_EQ 320
#define TOK_PRIVATE 321
#define TOK_PROGRAM_ID 322
#define TOK_PROTECTED 323
#define TOK_PREDEF 324
#define TOK_PUBLIC 325
#define TOK_RSH_EQ 326
#define TOK_STATIC 327
#define TOK_STRING_ID 328
#define TOK_SUB_EQ 329
#define TOK_TYPEDEF 330
#define TOK_TYPEOF 331
#define TOK_VARIANT 332
#define TOK_VOID_ID 333
#define TOK_WHILE 334
#define TOK_XOR_EQ 335
#define TOK_OPTIONAL 336




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 176 "/tmp/pikedeb.b138767487/7.4/src/language.yacc"
typedef union YYSTYPE {
  int number;
  FLOAT_TYPE fnum;
  struct node_s *n;
  char *str;
  void *ptr;
} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 207 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

==> pike7.4_7.4.341.orig.tar.gz: pike7.4-7.4.341.orig/src/language.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOK_ARROW = 258,
     TOK_CONSTANT = 259,
     TOK_FLOAT = 260,
     TOK_STRING = 261,
     TOK_NUMBER = 262,
     TOK_INC = 263,
     TOK_DEC = 264,
     TOK_RETURN = 265,
     TOK_EQ = 266,
     TOK_GE = 267,
     TOK_LE = 268,
     TOK_NE = 269,
     TOK_NOT = 270,
     TOK_LSH = 271,
     TOK_RSH = 272,
     TOK_LAND = 273,
     TOK_LOR = 274,
     TOK_SWITCH = 275,
     TOK_SSCANF = 276,
     TOK_CATCH = 277,
     TOK_FOREACH = 278,
     TOK_LEX_EOF = 279,
     TOK_ADD_EQ = 280,
     TOK_AND_EQ = 281,
     TOK_ARRAY_ID = 282,
     TOK_BREAK = 283,
     TOK_CASE = 284,
     TOK_CLASS = 285,
     TOK_COLON_COLON = 286,
     TOK_CONTINUE = 287,
     TOK_DEFAULT = 288,
     TOK_DIV_EQ = 289,
     TOK_DO = 290,
     TOK_DOT_DOT = 291,
     TOK_DOT_DOT_DOT = 292,
     TOK_ELSE = 293,
     TOK_ENUM = 294,
     TOK_EXTERN = 295,
     TOK_FLOAT_ID = 296,
     TOK_FOR = 297,
     TOK_FUNCTION_ID = 298,
     TOK_GAUGE = 299,
     TOK_GLOBAL = 300,
     TOK_IDENTIFIER = 301,
     TOK_IF = 302,
     TOK_IMPORT = 303,
     TOK_INHERIT = 304,
     TOK_INLINE = 305,
     TOK_LOCAL_ID = 306,
     TOK_FINAL_ID = 307,
     TOK_INT_ID = 308,
     TOK_LAMBDA = 309,
     TOK_MULTISET_ID = 310,
     TOK_MULTISET_END = 311,
     TOK_MULTISET_START = 312,
     TOK_LSH_EQ = 313,
     TOK_MAPPING_ID = 314,
     TOK_MIXED_ID = 315,
     TOK_MOD_EQ = 316,
     TOK_MULT_EQ = 317,
     TOK_NO_MASK = 318,
     TOK_OBJECT_ID = 319,
     TOK_OR_EQ = 320,
     TOK_PRIVATE = 321,
     TOK_PROGRAM_ID = 322,
     TOK_PROTECTED = 323,
     TOK_PREDEF = 324,
     TOK_PUBLIC = 325,
     TOK_RSH_EQ = 326,
     TOK_STATIC = 327,
     TOK_STRING_ID = 328,
     TOK_SUB_EQ = 329,
     TOK_TYPEDEF = 330,
     TOK_TYPEOF = 331,
     TOK_VARIANT = 332,
     TOK_VOID_ID = 333,
     TOK_WHILE = 334,
     TOK_XOR_EQ = 335,
     TOK_OPTIONAL = 336
   };
#endif
/* Tokens.  */
#define TOK_ARROW 258
#define TOK_CONSTANT 259
#define TOK_FLOAT 260
#define TOK_STRING 261
#define TOK_NUMBER 262
#define TOK_INC 263
#define TOK_DEC 264
#define TOK_RETURN 265
#define TOK_EQ 266
#define TOK_GE 267
#define TOK_LE 268
#define TOK_NE 269
#define TOK_NOT 270
#define TOK_LSH 271
#define TOK_RSH 272
#define TOK_LAND 273
#define TOK_LOR 274
#define TOK_SWITCH 275
#define TOK_SSCANF 276
#define TOK_CATCH 277
#define TOK_FOREACH 278
#define TOK_LEX_EOF 279
#define TOK_ADD_EQ 280
#define TOK_AND_EQ 281
#define TOK_ARRAY_ID 282
#define TOK_BREAK 283
#define TOK_CASE 284
#define TOK_CLASS 285
#define TOK_COLON_COLON 286
#define TOK_CONTINUE 287
#define TOK_DEFAULT 288
#define TOK_DIV_EQ 289
#define TOK_DO 290
#define TOK_DOT_DOT 291
#define TOK_DOT_DOT_DOT 292
#define TOK_ELSE 293
#define TOK_ENUM 294
#define TOK_EXTERN 295
#define TOK_FLOAT_ID 296
#define TOK_FOR 297
#define TOK_FUNCTION_ID 298
#define TOK_GAUGE 299
#define TOK_GLOBAL 300
#define TOK_IDENTIFIER 301
#define TOK_IF 302
#define TOK_IMPORT 303
#define TOK_INHERIT 304
#define TOK_INLINE 305
#define TOK_LOCAL_ID 306
#define TOK_FINAL_ID 307
#define TOK_INT_ID 308
#define TOK_LAMBDA 309
#define TOK_MULTISET_ID 310
#define TOK_MULTISET_END 311
#define TOK_MULTISET_START 312
#define TOK_LSH_EQ 313
#define TOK_MAPPING_ID 314
#define TOK_MIXED_ID 315
#define TOK_MOD_EQ 316
#define TOK_MULT_EQ 317
#define TOK_NO_MASK 318
#define TOK_OBJECT_ID 319
#define TOK_OR_EQ 320
#define TOK_PRIVATE 321
#define TOK_PROGRAM_ID 322
#define TOK_PROTECTED 323
#define TOK_PREDEF 324
#define TOK_PUBLIC 325
#define TOK_RSH_EQ 326
#define TOK_STATIC 327
#define TOK_STRING_ID 328
#define TOK_SUB_EQ 329
#define TOK_TYPEDEF 330
#define TOK_TYPEOF 331
#define TOK_VARIANT 332
#define TOK_VOID_ID 333
#define TOK_WHILE 334
#define TOK_XOR_EQ 335
#define TOK_OPTIONAL 336




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 176 "/tmp/pikedeb.5a120871e4/7.4/src/language.yacc"
typedef union YYSTYPE {
  int number;
  FLOAT_TYPE fnum;
  struct node_s *n;
  char *str;
  void *ptr;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 208 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif
